==> haskell-free-4.12.4-10-armv7h.pkg.tar.xz: usr/share/haskell/haskell-free/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: free
version: 4.12.4
id: free-4.12.4-4d7b26d357ab46561e822913cd7a6493
key: free_H3gabvSicISAtCHFi28Y0v
license: BSD3
copyright: Copyright (C) 2008-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/free/
synopsis: Monads for free
description:
    Free monads are useful for many tree-like structures and domain specific languages.
    .
    If @f@ is a '\''Functor'\'' then the free '\''Monad'\'' on @f@ is the type
    of trees whose nodes are labeled with the constructors of @f@. The word
    \"free\" is used in the sense of \"unrestricted\" rather than \"zero-cost\":
    @Free f@ makes no constraining assumptions beyond those given by @f@ and the
    definition of '\''Monad'\''. As used here it is a standard term from the
    mathematical theory of adjoint functors.
    .
    Cofree comonads are dual to free monads. They provide convenient ways to talk
    about branching streams and rose-trees, and can be used to annotate syntax
    trees. The cofree comonad can be seen as a stream parameterized by a '\''Functor'\''
    that controls its branching factor.
    .
    More information on free monads, including examples, can be found in the
    following blog posts:
    <http://comonad.com/reader/2008/monads-for-free/>
    <http://comonad.com/reader/2011/free-monads-for-less/>
category: Control, Monads
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Applicative.Free Control.Applicative.Free.Final
    Control.Applicative.Trans.Free Control.Alternative.Free
    Control.Alternative.Free.Final Control.Comonad.Cofree
    Control.Comonad.Cofree.Class Control.Comonad.Trans.Cofree
    Control.Comonad.Trans.Coiter Control.Monad.Free
    Control.Monad.Free.Church Control.Monad.Free.Class
    Control.Monad.Free.TH Control.Monad.Trans.Free
    Control.Monad.Trans.Free.Church Control.Monad.Trans.Iter
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/free-4.12.4
library-dirs: /usr/lib/ghc-7.10.3/site-local/free-4.12.4
data-dir: /usr/share/arm-linux-ghc-7.10.3/free-4.12.4
hs-libraries: HSfree-4.12.4-H3gabvSicISAtCHFi28Y0v
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bifunctors-5.3-b98299755d5303d55588251f793bb639
    comonad-5-e98e7adc8875accf64a86529d9aeae51
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    distributive-0.5.0.2-6c580c91b8bf5de803bfa850eb262f37
    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    prelude-extras-0.4.0.3-1ebda3e30d44e52e3bbcd33027a32ddc
    profunctors-5.2-a3b810f661c38ea494793460d496159b
    semigroupoids-5.0.1-53b0b3ecfca9d658a051ef7b22e11130
    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
haddock-interfaces: /usr/share/doc/haskell-free/html/free.haddock
haddock-html: /usr/share/doc/haskell-free/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-free-4.12.4-11-armv7h.pkg.tar.xz: usr/share/haskell/haskell-free/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: free
version: 4.12.4
id: free-4.12.4-f8dab736d0d811e91eb50084b5673f3a
key: free_7TQQfH6SOOb62MYhmoGomT
license: BSD3
copyright: Copyright (C) 2008-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/free/
synopsis: Monads for free
description:
    Free monads are useful for many tree-like structures and domain specific languages.
    .
    If @f@ is a '\''Functor'\'' then the free '\''Monad'\'' on @f@ is the type
    of trees whose nodes are labeled with the constructors of @f@. The word
    \"free\" is used in the sense of \"unrestricted\" rather than \"zero-cost\":
    @Free f@ makes no constraining assumptions beyond those given by @f@ and the
    definition of '\''Monad'\''. As used here it is a standard term from the
    mathematical theory of adjoint functors.
    .
    Cofree comonads are dual to free monads. They provide convenient ways to talk
    about branching streams and rose-trees, and can be used to annotate syntax
    trees. The cofree comonad can be seen as a stream parameterized by a '\''Functor'\''
    that controls its branching factor.
    .
    More information on free monads, including examples, can be found in the
    following blog posts:
    <http://comonad.com/reader/2008/monads-for-free/>
    <http://comonad.com/reader/2011/free-monads-for-less/>
category: Control, Monads
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Applicative.Free Control.Applicative.Free.Final
    Control.Applicative.Trans.Free Control.Alternative.Free
    Control.Alternative.Free.Final Control.Comonad.Cofree
    Control.Comonad.Cofree.Class Control.Comonad.Trans.Cofree
    Control.Comonad.Trans.Coiter Control.Monad.Free
    Control.Monad.Free.Church Control.Monad.Free.Class
    Control.Monad.Free.TH Control.Monad.Trans.Free
    Control.Monad.Trans.Free.Church Control.Monad.Trans.Iter
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/free-4.12.4
library-dirs: /usr/lib/ghc-7.10.3/site-local/free-4.12.4
data-dir: /usr/share/arm-linux-ghc-7.10.3/free-4.12.4
hs-libraries: HSfree-4.12.4-7TQQfH6SOOb62MYhmoGomT
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bifunctors-5.3-b6e9a28a0175204e65003b150c0bbe80
    comonad-5-3b2e208311908bc5a9db1ceb26126917
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    distributive-0.5.0.2-062a0a4262c71bd1a32922e0774f8a66
    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    prelude-extras-0.4.0.3-1ebda3e30d44e52e3bbcd33027a32ddc
    profunctors-5.2-026a1eb9905bccdb097d36481584da83
    semigroupoids-5.0.1-ab1721c6c7a72801e6cd851407a313ad
    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
haddock-interfaces: /usr/share/doc/haskell-free/html/free.haddock
haddock-html: /usr/share/doc/haskell-free/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
